pub struct NoContext;Expand description
An empty counter that will always return the value 0.
This type can be used when constructing version 7 UUIDs. When used to construct a version 7 UUID, the entire counter segment of the UUID will be filled with a random value. This type does not maintain ordering of UUIDs within a millisecond but is efficient.
This type should not be used when constructing version 1 or version 6 UUIDs. When used to construct a version 1 or version 6 UUID, the counter segment will remain zero.